-- *****************************************************************************
-- BeneCast Helper functions
-- *****************************************************************************

-- Function to clear the table given as the parameter
local function _ClearTable(Table, recursively)

	if Table ~= nil and type(Table) == 'table' then
		-- Removes every element of the table starting at the end
		local var, n = table.getn(Table);
		for i = n, 1, -1 do
			var = Table[i];
			if type(var) == 'table' and recursively then
				_ClearTable(var, true);
			end
			table.remove(Table);
		end
		return Table;
	else
		return {};
	end
	
end

local function _CopyTable(Table,recursive)
	if Tabel ~= nil then
		local new = {};
		for k, v in pairs(Table) do
			if (type(v) == 'table') and recursive then
				new[k] = _CopyTable(v,true);
			else
				new[k] = v;
			end
		end
		return new;
	else
		return nil;
	end
end

local function _CopyTableToExisting(source,destination,recursive)
	if source == nil or destination == nil then
		return;
	end
	for k, v in pairs(source) do
		if (type(v) == 'table') and recursive then
			destination[k] = _CopyTable(v,true);
		else
			destination[k] = v;
		end
	end
	return destination;
end

-- Function to determine if a unit is in your raid group
local function _UnitInRaid(unit)

	return UnitPlayerOrPetInRaid(unit);
	
end

-- Function to determine if a unitid is 'raid'..x
local function _UnitIsRaidID(unit)

	if string.find(unit,'raid') and not string.find(unit,'raidpet') then
		return true;
	end
	return nil;
	
end

-- Function to determine if a unitid is x..'pet'..y
local function _UnitIsPetID(unit)

	return string.find(unit, 'pet');
	
end

-- Function to determine if a unitid is 'raidpet'..x
local function _UnitIsRaidPetID(unit)

	return string.find(unit, 'raidpet');
	
end

-- Function to determine if a unit is a party pet
local function _UnitIsPartyPet(unit)

	return not UnitIsPlayer(unit) and UnitPlayerOrPetInParty(unit);
	
end

-- Function to determine if a unit is a raid pet
local function _UnitIsRaidPet(unit)

	return not UnitIsPlayer(unit) and UnitPlayerOrPetInRaid(unit);
	
end

-- Function to determine the owner of a raid pet
local function _GetRaidPetOwnerID(unit)
	return string.gsub(unit,'pet','');
end

-- Function to set a lot of attributes in one time
local function _SetManyAttributes(self, ...)
	for i=1,select("#", ...),2 do
		local att,val = select(i, ...);
		if not att then
			return;
		end
		self:SetAttribute(att,val);
	end
end
